==> jc-1.4.0.tar.gz: polyglot/visit/HaltingVisitor.h <==
// public abstract class polyglot.visit.HaltingVisitor

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_HaltingVisitor_H_
#define _JC_polyglot_visit_HaltingVisitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_HaltingVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_HaltingVisitor$sub_refs	_jc_polyglot_visit_HaltingVisitor$sub_refs;
typedef struct _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	_jc_polyglot_visit_HaltingVisitor$sub_nonrefs;
typedef struct _jc_polyglot_visit_HaltingVisitor$refs	_jc_polyglot_visit_HaltingVisitor$refs;
typedef struct _jc_polyglot_visit_HaltingVisitor$nonrefs	_jc_polyglot_visit_HaltingVisitor$nonrefs;
typedef struct _jc_polyglot_visit_HaltingVisitor$object	_jc_polyglot_visit_HaltingVisitor$object;

typedef const struct _jc_polyglot_visit_HaltingVisitor$vmethods	_jc_polyglot_visit_HaltingVisitor$vmethods;
typedef const struct _jc_polyglot_visit_HaltingVisitor$vtable	_jc_polyglot_visit_HaltingVisitor$vtable;
typedef const struct _jc_polyglot_visit_HaltingVisitor$vtype	_jc_polyglot_visit_HaltingVisitor$vtype;

// Constructors
extern void _jc_polyglot_visit_HaltingVisitor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *);

// Virtual methods
extern struct _jc_polyglot_visit_HaltingVisitor$object *_jc_polyglot_visit_HaltingVisitor$method$bypass$2362fe5b09e06e51(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *);
extern struct _jc_polyglot_visit_HaltingVisitor$object *_jc_polyglot_visit_HaltingVisitor$method$bypass$a2413c94f53e8bbe(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *);
extern struct _jc_polyglot_visit_HaltingVisitor$object *_jc_polyglot_visit_HaltingVisitor$method$bypassChildren$297f04895f89c850(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_polyglot_visit_HaltingVisitor$method$copy$2119f530248e04c9(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *);
extern struct _jc_object *_jc_polyglot_visit_HaltingVisitor$method$override$b414405487168b9b(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_polyglot_visit_HaltingVisitor$object *_jc_polyglot_visit_HaltingVisitor$method$visitChildren$8328a2f7ca5ebf6b(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_HaltingVisitor$method_info$bypass$2362fe5b09e06e51;
extern _jc_method _jc_polyglot_visit_HaltingVisitor$method_info$bypass$a2413c94f53e8bbe;
extern _jc_method _jc_polyglot_visit_HaltingVisitor$method_info$bypassChildren$297f04895f89c850;
extern _jc_method _jc_polyglot_visit_HaltingVisitor$method_info$copy$2119f530248e04c9;
extern _jc_method _jc_polyglot_visit_HaltingVisitor$method_info$override$b414405487168b9b;
extern _jc_method _jc_polyglot_visit_HaltingVisitor$method_info$visitChildren$8328a2f7ca5ebf6b;

// Virtual methods structure
struct _jc_polyglot_visit_HaltingVisitor$vmethods {
	struct _jc_polyglot_visit_HaltingVisitor$object	*(*bypass$2362fe5b09e06e51)(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *);
	struct _jc_polyglot_visit_HaltingVisitor$object	*(*bypass$a2413c94f53e8bbe)(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *);
	struct _jc_polyglot_visit_HaltingVisitor$object	*(*bypassChildren$297f04895f89c850)(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*copy$2119f530248e04c9)(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *);
	struct _jc_object	*(*override$b414405487168b9b)(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_polyglot_visit_HaltingVisitor$object	*(*visitChildren$8328a2f7ca5ebf6b)(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *);
};

// Vtable
struct _jc_polyglot_visit_HaltingVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
};

// Vtype
struct _jc_polyglot_visit_HaltingVisitor$vtype {
	_jc_type			type;
	_jc_polyglot_visit_HaltingVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_HaltingVisitor$sub_refs {
	struct _jc_object	*bypassParent;
	struct _jc_object	*bypass;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_HaltingVisitor$refs {
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_HaltingVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_HaltingVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
};

// Object instance structure
struct _jc_polyglot_visit_HaltingVisitor$object {
	_jc_polyglot_visit_HaltingVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_HaltingVisitor$vtype	*vtype;
	_jc_polyglot_visit_HaltingVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_HaltingVisitor$vtype _jc_polyglot_visit_HaltingVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_HaltingVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_HaltingVisitor$class_object;

#endif	/* _JC_polyglot_visit_HaltingVisitor_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/HaltingVisitor.h <==
// public abstract class polyglot.visit.HaltingVisitor

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_HaltingVisitor_H_
#define _JC_polyglot_visit_HaltingVisitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_HaltingVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_HaltingVisitor$sub_refs	_jc_polyglot_visit_HaltingVisitor$sub_refs;
typedef struct _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	_jc_polyglot_visit_HaltingVisitor$sub_nonrefs;
typedef struct _jc_polyglot_visit_HaltingVisitor$refs	_jc_polyglot_visit_HaltingVisitor$refs;
typedef struct _jc_polyglot_visit_HaltingVisitor$nonrefs	_jc_polyglot_visit_HaltingVisitor$nonrefs;
typedef struct _jc_polyglot_visit_HaltingVisitor$object	_jc_polyglot_visit_HaltingVisitor$object;

typedef const struct _jc_polyglot_visit_HaltingVisitor$vmethods	_jc_polyglot_visit_HaltingVisitor$vmethods;
typedef const struct _jc_polyglot_visit_HaltingVisitor$vtable	_jc_polyglot_visit_HaltingVisitor$vtable;
typedef const struct _jc_polyglot_visit_HaltingVisitor$vtype	_jc_polyglot_visit_HaltingVisitor$vtype;

// Constructors
extern void _jc_polyglot_visit_HaltingVisitor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_visit_HaltingVisitor$object *_jc_polyglot_visit_HaltingVisitor$method$bypass$2362fe5b09e06e51(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_HaltingVisitor$object *_jc_polyglot_visit_HaltingVisitor$method$bypass$a2413c94f53e8bbe(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_HaltingVisitor$object *_jc_polyglot_visit_HaltingVisitor$method$bypassChildren$297f04895f89c850(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_polyglot_visit_HaltingVisitor$method$copy$2119f530248e04c9(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_HaltingVisitor$method$override$b414405487168b9b(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_HaltingVisitor$object *_jc_polyglot_visit_HaltingVisitor$method$visitChildren$8328a2f7ca5ebf6b(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_HaltingVisitor$method_info$bypass$2362fe5b09e06e51;
extern _jc_method _jc_polyglot_visit_HaltingVisitor$method_info$bypass$a2413c94f53e8bbe;
extern _jc_method _jc_polyglot_visit_HaltingVisitor$method_info$bypassChildren$297f04895f89c850;
extern _jc_method _jc_polyglot_visit_HaltingVisitor$method_info$copy$2119f530248e04c9;
extern _jc_method _jc_polyglot_visit_HaltingVisitor$method_info$override$b414405487168b9b;
extern _jc_method _jc_polyglot_visit_HaltingVisitor$method_info$visitChildren$8328a2f7ca5ebf6b;

// Virtual methods structure
struct _jc_polyglot_visit_HaltingVisitor$vmethods {
	struct _jc_polyglot_visit_HaltingVisitor$object	*(*bypass$2362fe5b09e06e51)(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_HaltingVisitor$object	*(*bypass$a2413c94f53e8bbe)(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_HaltingVisitor$object	*(*bypassChildren$297f04895f89c850)(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*copy$2119f530248e04c9)(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*override$b414405487168b9b)(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_HaltingVisitor$object	*(*visitChildren$8328a2f7ca5ebf6b)(_jc_env *, struct _jc_polyglot_visit_HaltingVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_HaltingVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
};

// Vtype
struct _jc_polyglot_visit_HaltingVisitor$vtype {
	_jc_type			type;
	_jc_polyglot_visit_HaltingVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_HaltingVisitor$sub_refs {
	struct _jc_object	*bypassParent;
	struct _jc_object	*bypass;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_HaltingVisitor$refs {
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_HaltingVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_HaltingVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
};

// Object instance structure
struct _jc_polyglot_visit_HaltingVisitor$object {
	_jc_polyglot_visit_HaltingVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_HaltingVisitor$vtype	*vtype;
	_jc_polyglot_visit_HaltingVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_HaltingVisitor$vtype _jc_polyglot_visit_HaltingVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_HaltingVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_HaltingVisitor$class_object;

#endif	/* _JC_polyglot_visit_HaltingVisitor_H_ */
